==> nmrium-0.50.1.tgz: package/lib/component/reducer/preferences/actions/analyzeSpectra.js <==
import * as MultipleAnalysis from '../../../../data/data1d/multipleSpectraAnalysis';
import { orderRange } from '../../helper/getRange';
import { getMultipleSpectraAnalysisDefaultValues } from '../panelsPreferencesDefaultValues';
import { getActiveWorkspace } from '../utilities/getActiveWorkspace';
export function analyzeSpectra(draft, action) {
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.formatting.panels;
    const { start, end, nucleus, columnKey } = action.payload;
    if (!panels.multipleSpectraAnalysis) {
        panels.multipleSpectraAnalysis =
            getMultipleSpectraAnalysisDefaultValues(nucleus);
    }
    const [from, to] = orderRange(start, end);
    MultipleAnalysis.analyzeSpectra(panels.multipleSpectraAnalysis, {
        from,
        to,
        nucleus,
        columnKey,
    });
}
export function changeAnalysisColumnValueKey(draft, action) {
    const { columnKey, valueKey, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.formatting.panels;
    MultipleAnalysis.changeColumnValueKey(panels.multipleSpectraAnalysis, nucleus, columnKey, valueKey);
}
export function deleteAnalysisColumn(draft, action) {
    const { columnKey, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.formatting.panels;
    MultipleAnalysis.deleteSpectraAnalysis(panels.multipleSpectraAnalysis, columnKey, nucleus);
}
export function setSpectraAnalysisPanelsPreferences(draft, action) {
    if (action.payload) {
        const currentWorkspacePreferences = getActiveWorkspace(draft);
        const { nucleus, data } = action.payload;
        const panels = currentWorkspacePreferences.formatting.panels;
        if (!panels?.multipleSpectraAnalysis) {
            panels.multipleSpectraAnalysis =
                getMultipleSpectraAnalysisDefaultValues(nucleus);
        }
        const { analysisOptions, legendsFields } = data;
        panels.multipleSpectraAnalysis[nucleus] = {
            legendsFields,
            analysisOptions: MultipleAnalysis.mapColumns(analysisOptions),
        };
    }
}

==> nmrium-0.55.0.tgz: package/lib/component/reducer/preferences/actions/analyzeSpectra.js <==
import * as MultipleAnalysis from '../../../../data/data1d/multipleSpectraAnalysis';
import { orderRange } from '../../helper/getRange';
import { getMultipleSpectraAnalysisDefaultValues } from '../panelsPreferencesDefaultValues';
import { getActiveWorkspace } from '../utilities/getActiveWorkspace';
export function analyzeSpectra(draft, action) {
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.panels;
    const { start, end, nucleus, columnKey } = action.payload;
    if (!panels.multipleSpectraAnalysis) {
        panels.multipleSpectraAnalysis =
            getMultipleSpectraAnalysisDefaultValues(nucleus);
    }
    const [from, to] = orderRange(start, end);
    MultipleAnalysis.analyzeSpectra(panels.multipleSpectraAnalysis, {
        from,
        to,
        nucleus,
        columnKey,
    });
}
export function changeAnalysisColumnValueKey(draft, action) {
    const { columnKey, valueKey, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.panels;
    MultipleAnalysis.changeColumnValueKey(panels.multipleSpectraAnalysis, nucleus, columnKey, valueKey);
}
export function deleteAnalysisColumn(draft, action) {
    const { columnKey, nucleus } = action.payload;
    const currentWorkspacePreferences = getActiveWorkspace(draft);
    const panels = currentWorkspacePreferences.panels;
    MultipleAnalysis.deleteSpectraAnalysis(panels.multipleSpectraAnalysis, columnKey, nucleus);
}
export function setSpectraAnalysisPanelsPreferences(draft, action) {
    if (action.payload) {
        const currentWorkspacePreferences = getActiveWorkspace(draft);
        const { nucleus, data } = action.payload;
        const panels = currentWorkspacePreferences.panels;
        if (!panels?.multipleSpectraAnalysis) {
            panels.multipleSpectraAnalysis =
                getMultipleSpectraAnalysisDefaultValues(nucleus);
        }
        const { analysisOptions, legendsFields } = data;
        panels.multipleSpectraAnalysis[nucleus] = {
            legendsFields,
            analysisOptions: MultipleAnalysis.mapColumns(analysisOptions),
        };
    }
}
